@@ -157,12 +157,7 @@ fn process_csv(
 
         if record.get(field_num).is_some() {
             let rec = record.get(field_num).unwrap();
-            let parts: Vec<&str> = rec.split('/').collect();
-            if parts.len() < 2 {
-                eprintln!("{}: not in ip/cidr format", rec);
-                continue;
-            }
-
+            let mut parts: Vec<&str> = rec.split('/').collect();
             let mut row_ip: Option<Addr> = None;
 
             if parts[0].contains(':') {
@@ -170,6 +165,10 @@ fn process_csv(
                     *rows = Some(HashMap::new());
                 }
 
+                if parts.len() == 1 {
+                    parts.push("128");
+                }
+
                 let v6 = parse_v6(
                     parts[0],
                     input_base,
@@ -193,6 +192,9 @@ fn process_csv(
                     input_base,
                     matches!(reverse, Reverse::Both | Reverse::Source),
                 );
+                if parts.len() == 1 {
+                    parts.push("32");
+                }
 
                 if v4.is_none() {
                     eprintln!("{}: not in ip/cidr format", rec);
@@ -592,10 +594,10 @@ fn main() {
     }
 
     if input_mask.is_none() && matches.free.is_empty() {
-        input_mask = Some(24);
+        input_mask = Some(32);
 
         if let Some(Addr::V6(_)) = input_ip {
-            input_mask = Some(64);
+            input_mask = Some(128);
         }
     }
 
@@ -606,6 +608,14 @@ fn main() {
         });
     }
 
+    if !matches.opt_present("inside")
+        && !matches.opt_present("outside")
+        && matches.opt_present("encapsulating")
+        && !matches.opt_present("mask")
+    {
+        input_mask = Some(32);
+    }
+
     let free_arg = matches.free.clone();
     if !free_arg.is_empty() {
         for arg in &free_arg {
@@ -664,6 +674,7 @@ fn main() {
             if matches.opt_present("group") {
                 network_size = matches.opt_str("group").unwrap().trim().parse().unwrap();
             }
+
             process_encapsulated_input(
                 &matches,
                 inside,
